[−][src]Struct alacritty::event::Processor
The event processor.
Stores some state from received events and dispatches actions when they are triggered.
Fields
notifier: Nmouse: Mousereceived_count: usizesuppress_chars: boolclipboard: Clipboardmodifiers: ModifiersStateconfig: TermConfig<UIConfig>message_buffer: MessageBufferdisplay: Displayfont_size: Sizeevent_queue: Vec<GlutinEvent<'static, Event>>search_state: SearchStatecli_options: CLIOptionsImplementations
impl<N: Notify + OnResize> Processor<N>[src]
pub fn new(
notifier: N,
message_buffer: MessageBuffer,
config: TermConfig<UIConfig>,
display: Display,
cli_options: CLIOptions
) -> Processor<N>[src]
notifier: N,
message_buffer: MessageBuffer,
config: TermConfig<UIConfig>,
display: Display,
cli_options: CLIOptions
) -> Processor<N>
Create a new event processor.
Takes a writer which is expected to be hooked up to the write end of a PTY.
fn event_queue_empty(&mut self) -> bool[src]
Return true if event_queue is empty, false otherwise.
pub fn run<T>(
&mut self,
terminal: Arc<FairMutex<Term<T>>>,
event_loop: EventLoop<Event>
) where
T: EventListener, [src]
&mut self,
terminal: Arc<FairMutex<Term<T>>>,
event_loop: EventLoop<Event>
) where
T: EventListener,
Run the event loop.
fn handle_event<T>(
event: GlutinEvent<'_, Event>,
processor: &mut Processor<'_, T, ActionContext<'_, N, T>>
) where
T: EventListener, [src]
event: GlutinEvent<'_, Event>,
processor: &mut Processor<'_, T, ActionContext<'_, N, T>>
) where
T: EventListener,
Handle events from glutin.
Doesn't take self mutably due to borrow checking.
fn skip_event(event: &GlutinEvent<'_, Event>) -> bool[src]
Check if an event is irrelevant and can be skipped.
fn reload_config<T>(
path: &PathBuf,
processor: &mut Processor<'_, T, ActionContext<'_, N, T>>
) where
T: EventListener, [src]
path: &PathBuf,
processor: &mut Processor<'_, T, ActionContext<'_, N, T>>
) where
T: EventListener,
fn submit_display_update<T>(
&mut self,
terminal: &mut Term<T>,
old_is_searching: bool,
display_update_pending: DisplayUpdate
) where
T: EventListener, [src]
&mut self,
terminal: &mut Term<T>,
old_is_searching: bool,
display_update_pending: DisplayUpdate
) where
T: EventListener,
Submit the pending changes to the Display.
fn write_ref_test_results<T>(&self, terminal: &Term<T>)[src]
Write the ref test results to the disk.